@@ -315,7 +315,7 @@ impl Request {
             method: method.to_string(),
             params,
             id: Some(Value::Number(Number::from(
-                rand::thread_rng().gen_range(0..std::u32::MAX) + 1,
+                rand::thread_rng().gen_range(1..std::u32::MAX),
             ))),
         }
     }
@@ -405,19 +405,6 @@ pub struct Response {
 }
 
 impl Response {
-    /// Create a response that is a notification.
-    ///
-    /// Typically used to broadcast messages to multiple connected 
-    /// clients.
-    pub fn new_notification(result: Option<Value>) -> Self {
-        Self {
-            jsonrpc: VERSION.to_string(),
-            result,
-            error: None,
-            id: None,
-        } 
-    }
-
     /// The id for the response.
     pub fn id(&self) -> &Option<Value> {
         &self.id
@@ -474,6 +461,17 @@ impl<'a> From<&'a mut Request> for Response {
     }
 }
 
+impl From<Value> for Response {
+    fn from(result: Value) -> Self {
+        Self {
+            jsonrpc: VERSION.to_string(),
+            result: Some(result),
+            error: None,
+            id: None,
+        }
+    }
+}
+
 mod test {
     use super::*;
 
